#!/bin/sh

# A simple script to run the cf-zserver
# fetches connectors from the cfrepo
# should be run in the .../cf/engine/src directory

unset CF_BASE_PATH
export CF_MODULE_PATH=`cd ../../builder/modules; pwd`
export CF_REPO_AUTH_URL=http://cfrepo.indexdata.com/auth.xml
export CF_REPO_FETCH_URL=http://cfrepo.indexdata.com/repo.pl/%s.cf
export CF_APP_PATH=`pwd`

set | grep ^CF_
echo "DISPLAY=$DISPLAY"
echo ""

./cf-zserver -p my.pid @:9020

